Skip to contents

freshwater provides a number of default views that are served to HTML clients in the event of common HTTP error codes.

Usage

default_error_500_template(
  error = NULL,
  request = NULL,
  is_debug = FALSE,
  ...,
  fragment = NULL
)

default_error_404_template(error = NULL, request = NULL, ..., fragment = NULL)

default_error_403_template(error = NULL, request = NULL, ..., fragment = NULL)

Arguments

error

the error condition signaled by an error in the server's route handler

request

the reqres::Request request object the handler is responding to

is_debug

whether to provide the stack trace and error message to the web client. Although useful during development, it is heavily recommended to set as FALSE in production as it can leak sensitive information.

...

unused

fragment

unused