HTML Document Root
document.RdConstructs a full HTML document. It does not modify or validate its contents.
document() is used for full-page responses, and should not be used for partials, fragments
or nested templates.
Value
An htmltools::tagList, consisting of a doctype declaration, an tag, and
user-supplied content.