Apply template function to each element of a vector
map_tags.Rdmap_tags() returns a type-safe tag list,
where each element is resolved by applying .f to each
element of .x. If an element in .x is a falsey value
(i.e. NA, NaN, FALSE, or NULL), the fallback value
from .empty is used.
Additional arguments should be passed with an anonymous function.
Details
Element values are evaluated prior to returning the tag list:
NULL values are removed from the final tag list. The return length of
map_tags()is therefore less than or equal to the length of.xAll return values must be either a "shiny.tag", "shiny.tag.list", or "character" vector. An error is raised if an unexpected value is encountered.